@@ -1,8 +1,9 @@
 PS1='$ '
 TOMCAT_DST_FOLDER="tomcat"
+TOMCAT_VERSION="7.0.67"
 TOMCAT_PID_FILENAME="tomcat.pid"
-SMARTGEAR_DISTRIBUTION_DIRECTORY="smartgears-distribution-*"
-SMARTGEAR_ROOT=/
+SMARTGEAR_DISTRIBUTION_DIRECTORY=$(ls -d smartgears-distribution-*)
+SMARTGEAR_ROOT=${PWD}
 
 BUNDLE_HOME=${SMARTGEAR_ROOT}
 STARTUP_SCRIPT="startContainer.sh"
@@ -68,8 +69,7 @@ function change_line {
     local FILE=$1
 
     local NEW=$(echo "${NEW_LINE}" | escape_slashes)
-    local OLD=$(echo "${OLD_LINE_PATTERN}" | escape_slashes)
-    sed -i '/'"${OLD}"'/s/.*/'"${NEW}"'/' "${FILE}"
+    sed -i '/'"${OLD_LINE_PATTERN}"'/s/.*/'"${NEW}"'/' "${FILE}"
 }
 
 while getopts ":n:fh" opt; do
@@ -87,7 +87,7 @@ done
 
 if [ $force ]; then
 	echo "Creating tomcat symlink..."
-	ln -s apache-tomcat-* ${TOMCAT_DST_FOLDER}
+	ln -s apache-tomcat-${TOMCAT_VERSION} ${TOMCAT_DST_FOLDER}
 	echo "done."
 	ls -l ${TOMCAT_DST_FOLDER}
 
@@ -119,7 +119,7 @@ if [ $force ]; then
 	source ~/.bashrc
 	
 	echo -e "\n"
-	echo -e "Entering on SmartGear distribution directory\n"
+	echo -e "Entering on SmartGear distribution directory ${SMARTGEAR_DISTRIBUTION_DIRECTORY}\n"
 	export CATALINA_HOME=${SMARTGEAR_ROOT}/${TOMCAT_DST_FOLDER}
 	cd ${SMARTGEAR_DISTRIBUTION_DIRECTORY}
 	
@@ -146,7 +146,7 @@ else
 	
 	echo ""
 	echo "Create tomcat symlink with the following command:"
-	echo "ln -s apache-tomcat-* ${TOMCAT_DST_FOLDER}"
+	echo "ln -s apache-tomcat-${TOMCAT_VERSION} ${TOMCAT_DST_FOLDER}"
 		
 	echo ""
 	echo "Add the following variables to your ~/.bashrc"
